function [vx, vy] = computeVelocity (ux, uy, vp, nsize, vlim)
% [vx, vy] = computeVelocity (ux, uy, vp, nsize, step, vlim)
% given the input x and y components of the unit vectors in the direction
% of the gradient, stored in the matrices ux and uy, and the perpendicular 
% components stored in vp, computes a 2-D velocity consistent with these 
% components. nsize is the size of the region for integrating the 
% perpendicular motions and vlim is a limit on the size of Vx and Vy that 
% is considered valid. Results are stored in the output matrices vx and vy
[rows, cols] = size(ux);
vx = zeros(rows, cols);      % create output matrices
vy = zeros(rows, cols);
for row = nsize+1:rows-nsize       % loop through rows and columns
    for col = nsize+1:cols-nsize  
        % calculate coefficients
        a1 = sum(sum(ux(row-nsize:row+nsize, col-nsize:col+nsize).^2));
        b1 = sum(sum(ux(row-nsize:row+nsize, col-nsize:col+nsize) .* ...
                     uy(row-nsize:row+nsize, col-nsize:col+nsize)));
        c1 = sum(sum(ux(row-nsize:row+nsize, col-nsize:col+nsize) .* ...
                     vp(row-nsize:row+nsize, col-nsize:col+nsize)));
        b2 = sum(sum(uy(row-nsize:row+nsize, col-nsize:col+nsize).^2));
        c2 = sum(sum(uy(row-nsize:row+nsize, col-nsize:col+nsize) .* ...
                     vp(row-nsize:row+nsize, col-nsize:col+nsize)));
        % calculate velocity at this location and store in vx, vy matrices
        temp = a1*b2 - b1^2;
        if (temp > 0.00001)     % avoids approximate division by 0
            vxval = (c1*b2 - b1*c2)/temp;
            vyval = (a1*c2 - b1*c1)/temp;
            if (abs(vxval) <= vlim) && (abs(vyval) <= vlim)
                vx(row, col) = vxval;
                vy(row, col) = vyval;
            end
        end
    end
end
