% motionTest.m
% script with two examples to test the getMotionComps function

% Example 1: circle translating down and to the right

% create test image sequence and compute convolutions
% these first 7 statements only need to be executed once
im1 = zeros(200, 200);
im1 = addCircle(im1, 100, 100, 50, 100);
im2 = zeros(200, 200);
im2 = addCircle(im2, 101, 101, 50, 100);
lap8 = laplacian(8.0);
c1 = conv2D(im1,lap8);
c2 = conv2D(im2,lap8);

% compute the perpendicular components of motion
[ux, uy, vp] = getMotionComps(c1, c2, 3);

% display ux, uy, and vp as images
figure('Position', [100 100 800 300])
subplot(1, 3, 1)
imshow(ux, [])
title('ux, -1 to +1', 'Fontsize', 16)
subplot(1, 3, 2)
imshow(uy, [])
title('uy, -1 to +1', 'Fontsize', 16)
subplot(1, 3, 3)
imshow(vp, [])
title('vp, roughly -1.16 to +1.33', 'Fontsize', 16)

% compute 2D velocity field from the perpendicular components of motion
[vx, vy] = computeVelocity(ux, uy, vp, 40, 3);

% display the computed velocity vectors superimposed on the convolution c2
figure('Position', [100 100 600 600])
imshow(c2, [], 'InitialMagnification', 'fit')
hold on
displayV(vx, vy, 15, 10);
title('c2 with velocity field (not to scale)', 'Fontsize', 20)

% % Example 2: redsox images
% % true motion: upper left region: motion down and to the right
% %              lower left region: motion up and to the left
% %              upper right region: motion to the right
% %              lower right region: motion to the left
% 
% % load redsox images and compute convolutions
% % these first five statements only need to be executed once
% redsox1 = imread('redsox1.jpg');
% redsox2 = imread('redsox2.jpg');
% lap8 = laplacian(8.0);
% c1 = conv2D(redsox1, lap8);
% c2 = conv2D(redsox2, lap8);
% 
% % compute the perpendicular components of motion
% [ux, uy, vp] = getMotionComps(c1, c2, 3);
% 
% % display ux, uy, and vp as images
% figure('Position', [100 100 800 300])
% subplot(1, 3, 1)
% imshow(ux, [])
% title('ux, -1 to +1', 'Fontsize', 16)
% subplot(1, 3, 2)
% imshow(uy, [])
% title('uy, -1 to +1', 'Fontsize', 16)
% subplot(1, 3, 3)
% imshow(vp, [])
% title('vp, roughly -1.16 to +1.33', 'Fontsize', 16)
% 
% % compute the 2D velocity field
% [vx, vy] = computeVelocity(ux, uy, vp, 25, 3);
% 
% % display the computed velocity vectors superimposed on the convolution c2
% figure('Position', [100 100 700 700])
% imshow(c2, [], 'InitialMagnification', 'fit')
% hold on
% displayV(vx, vy, 15, 15);
% title('c2 with velocity field (not to scale)', 'Fontsize', 20)
