% codeTips.m
% examples of new MATLAB functions and coding tips that may be helpful for
% completing the programming problem on Assignment 3

clear all               % clear all variables in workspace
close all               % close all figure windows
imtool close all        % close all imtool windows

% load a simple test image and convert to double type
im = double(imread('testIm.png'));
blobs = zeros(100,100);         % create matrix to store blob locations
for row = 6:95
    for col = 6:95
        % store a 1 (true) in blobs matrix at locations where the average 
        % brightness in im1 (within a surrounding neighborhood) is > 120
        blobs(row, col) = (mean(mean(im(row-5:row+5, col-5:col+5))) > 120);
    end
end

% compute connected components of blobs matrix, considering all 8 neighbors
[labels, n] = bwlabel(blobs, 8);
disp(['there are ' num2str(n) ' initial connected components'])
% open new figure window of size 600x600 pixels, located 100 pixels from
% left and bottom edges of the computer screen
figure('Position', [100 100 600 600])
% create a 2x2 arrangement of display areas to show im, blobs, and labels
subplot(2,2,1)
imshow(im, [])
title('original image', 'FontSize', 16)
subplot(2,2,2)
imshow(blobs, [])
title('high average brightness', 'FontSize', 16)
subplot(2,2,3)
imshow(labels, [])
title('all connected components (1-5)', 'FontSize', 16)

% remove the two small components from blobs (components labelled 1 and 5)
for i = [1 5]
    blobs(labels == i) = 0;
end
% recompute connected components of blobs matrix and display results
[labels, n] = bwlabel(blobs, 8);  
subplot(2,2,4)
imshow(labels, [])
title('large connected components', 'FontSize', 16)

% get the coordinates of the centroids of each connected component - in
% this case, regionprops returns a vector of 3 structures, where each 
% structure has one field named Centroid that contains a two-element vector 
% with the two coordinates of the centroid of the corresponding component
centers = regionprops(labels, 'Centroid');
% open a new figure window to show the centroids superimposed on the 
% connected components, and line segments connecting the centroids
figure('Position', [200 100 500 500])
imshow(labels, [], 'InitialMagnification', 'fit')
hold on           % keep current contents visible as new graphics are added
for i = 1:n
    % use scatter to display each center dot
    % note the use of the elipsis, ..., to break up long code lines!
    scatter(centers(i).Centroid(1), centers(i).Centroid(2), 100, 'r', ...
             'filled')
    % use plot to display connecting line segments
    if (i < n)   % connect centers of components with adjacent labels
        plot([centers(i).Centroid(1) centers(i+1).Centroid(1)], ...
             [centers(i).Centroid(2) centers(i+1).Centroid(2)], 'g', ...
             'LineWidth', 2)
    else     % connect the last center back to the first center
        plot([centers(n).Centroid(1) centers(1).Centroid(1)], ...
             [centers(n).Centroid(2) centers(1).Centroid(2)], 'g', ...
             'LineWidth', 2)
    end
end

        




